gs_quant.timeseries.econometrics.index — gs_quant 0.1 documentation

# gs_quant.timeseries.econometrics.index

`index`(x, initial=1)

  Geometric series normalization

  Parameters

    - x (`Series`) – time series

    - initial (`int`) – initial value

  Return type

    `Series`

  Returns

    normalized time series

  Usage

  Divides every value in x by the initial value of x:

  \(Y_t = initial * X_t / X_0\)

  where \(X_0\) is the first value in the series

  Examples

  Normalize series to 1:

      >>> series = generate_series(100)
      >>> returns = index(series)

  See also

  `returns()`